@@ -67,6 +67,8 @@ class Paths(object):
     @property
     def LOG_FILE(self):
         return os.path.expanduser('~/.instack/install-undercloud.log')
+
+
 PATHS = Paths()
 DEFAULT_LOG_LEVEL = logging.DEBUG
 DEFAULT_LOG_FORMAT = '%(asctime)s %(levelname)s: %(message)s'
@@ -309,9 +311,10 @@ _opts = [
                 help=('Whether to install requirements to run the TripleO '
                       'validations.')
                 ),
-    cfg.BoolOpt('ipxe_deploy',
+    cfg.BoolOpt('ipxe_enabled',
                 default=True,
-                help=('Whether to use iPXE for deploy by default.')
+                help=('Whether to use iPXE for deploy and inspection.'),
+                deprecated_name='ipxe_deploy',
                 ),
     cfg.BoolOpt('store_events',
                 default=False,
@@ -987,6 +990,13 @@ def _run_instack(instack_env):
     LOG.info('Instack completed successfully')
 
 
+def _run_yum_update(instack_env):
+    args = ['sudo', 'yum', 'update', '-y']
+    LOG.info('Running yum update')
+    _run_live_command(args, instack_env, 'yum-update')
+    LOG.info('yum-update completed successfully')
+
+
 def _run_orc(instack_env):
     args = ['sudo', 'os-refresh-config']
     LOG.info('Running os-refresh-config')
@@ -1199,6 +1209,7 @@ def install(instack_root):
     _validate_configuration()
     instack_env = _generate_environment(instack_root)
     _generate_init_data(instack_env)
+    _run_yum_update(instack_env)
     _run_instack(instack_env)
     _run_orc(instack_env)
     _post_config(instack_env)
